eBay API Settings Editor
=============================

This packages allows to set and check the eBay API Settings from ~/.ebay/config.yaml

This is a config file you can use with:
https://github.com/timotheus/ebaysdk-python
